@@ -401,10 +401,7 @@ sub parse {
                     # ISO 8601; 2000-04-29T01:23:45
                     $v->{'Y'} = int $1;
                     $v->{'M'} = $MonthName->{'abbr'}->[int($2) - 1];
-
-                    if( $3 < 32 ) {
-                        $v->{'d'} = int $3;
-                    }
+                    $v->{'d'} = int $3 if $3 < 32;
 
                     if( $4 < 24 && $5 < 60 && $6 < 60 ) {
                         $v->{'T'} = sprintf("%02d:%02d:%02d", $4, $5, $6);
@@ -416,6 +413,12 @@ sub parse {
                     $v->{'d'}  = int $2;
                     $v->{'Y'}  = int($3) + 2000;
                     $v->{'Y'} -= 100 if $v->{'Y'} > Time::Piece->new->year() + 1;
+
+                } elsif( $p =~ m|\A(\d{1,2})[-/](\d{1,2})[-/](\d{4})| ) {
+                    # 29-04-2017 22:22
+                    $v->{'d'} = int $1 if $1 < 32;
+                    $v->{'M'} = $MonthName->{'abbr'}->[int($2) - 1];
+                    $v->{'Y'} = int($3);
                 }
             }
         }
@@ -586,7 +589,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
