@@ -261,7 +261,8 @@ sub makeorder {
     my $heads = shift || return [];
     my $order = [];
 
-    return [] unless length $heads->{'subject'};
+    return [] unless exists $heads->{'subject'};
+    return [] unless $heads->{'subject'};
 
     # Try to match the value of "Subject" with patterns generated by
     # Sisimai::Order::Email->by('subject') method
