@@ -3,18 +3,18 @@ use strict;
 use warnings;
 
 sub is_reserved {
-    # Whether domain part is Reserved or not
+    # Whether a domain part is reserved or not
     # @param    [String] argv1  Domain part
     # @return   [Integer]       1: is Reserved top level domain
     #                           0: is NOT reserved top level domain
     # @see      http://www.ietf.org/rfc/rfc2606.txt
     my $class = shift;
-    my $argv1 = shift || return 0;
+    my $argv1 = shift || return undef;
 
-    return 1 if $argv1 =~ m/[.](?:test|example|invalid|localhost)\z/;
-    return 1 if $argv1 =~ m/example[.](?:com|net|org)\z/;
-    return 1 if $argv1 =~ m/example[.]jp\z/;
-    return 1 if $argv1 =~ m/example[.](?:ac|ad|co|ed|go|gr|lg|ne|or)[.]jp\z/;
+    return 1 if $argv1 =~ /[.](?:test|example|invalid|localhost)\z/;
+    return 1 if $argv1 =~ /example[.](?:com|net|org)\z/;
+    return 1 if $argv1 =~ /example[.]jp\z/;
+    return 1 if $argv1 =~ /example[.](?:ac|ad|co|ed|go|gr|lg|ne|or)[.]jp\z/;
     return 0;
 }
 
