@@ -16,15 +16,20 @@ sub match {
     my $regex = qr{(?>
          access[ ]denied[.][ ]IP[ ]name[ ]lookup[ ]failed
         |access[ ]from[ ]ip[ ]address[ ].+[ ]blocked
+        |all[ ]mail[ ]servers[ ]must[ ]have[ ]a[ ]PTR[ ]record[ ]with[ ]a[ ]valid[ ]Reverse[ ]DNS[ ]entry
+        |Bad[ ]sender[ ]IP[ ]address
         |blacklisted[ ]by
-        |Blocked[ ]-[ ]see[ ]https://support[.]proofpoint[.]com/dnsbl-lookup[.]cgi[?]ip=.+
+        |(?:Blocked|Refused)[ ]-[ ]see[ ]https?://
         |can[']t[ ]determine[ ]Purported[ ]Responsible[ ]Address
         |cannot[ ]resolve[ ]your[ ]address
-        |client[ ]host[ ].+[ ]blocked[ ]using
-        |client[ ]host[ ]rejected:[ ](?:
-             may[ ]not[ ]be[ ]mail[ ]exchanger
-            |cannot[ ]find[ ]your[ ]hostname    # Yahoo!
-            |was[ ]not[ ]authenticated          # Microsoft
+        |client[ ]host[ ](?:
+             .+[ ]blocked[ ]using
+            |rejected:[ ](?:
+                 Abus[ ]detecte[ ]GU_EIB_0[24]      # SFR
+                |cannot[ ]find[ ]your[ ]hostname    # Yahoo!
+                |may[ ]not[ ]be[ ]mail[ ]exchanger
+                |was[ ]not[ ]authenticated          # Microsoft
+                )
             )
         |confirm[ ]this[ ]mail[ ]server
         |connection[ ](?:
@@ -33,39 +38,105 @@ sub match {
            |reset[ ]by[ ]peer
            |was[ ]dropped[ ]by[ ]remote[ ]host
            )
-        |domain[ ]does[ ]not[ ]exist:
-        |domain[ ].+[ ]mismatches[ ]client[ ]ip
+        |Connections[ ](?:
+             not[ ]accepted[ ]from[ ]IP[ ]addresses[ ]on[ ]Spamhaus[ ]XBL
+            |will[ ]not[ ]be[ ]accepted[ ]from[ ].+because[ ]the[ ]ip[ ]is[ ]in[ ]Spamhaus's[ ]list
+            )
+        |Currently[ ]Sending[ ]Spam[ ]See:[ ]
+        |domain[ ](?:
+             .+[ ]mismatches[ ]client[ ]ip
+            |does[ ]not[ ]exist:
+            )
         |dns[ ]lookup[ ]failure:[ ].+[ ]try[ ]again[ ]later
         |DNSBL:ATTRBL
+        |Dynamic/zombied/spam[ ]IPs[ ]blocked
+        |Email[ ]blocked[ ]by[ ](?:.+[.]barracudacentral[.]org|SPAMHAUS)
+        |Fix[ ]reverse[ ]DNS[ ]for[ ].+
         |Go[ ]away
+        |host[ ].+[ ]refused[ ]to[ ]talk[ ]to[ ]me:[ ]\d+[ ]Blocked
         |hosts[ ]with[ ]dynamic[ ]ip
+        |http://(?:
+             spf[.]pobox[.]com/why[.]html
+            |www[.]spamcop[.]net/bl[.]
+            )
+        |INVALID[ ]IP[ ]FOR[ ]SENDING[ ]MAIL[ ]OF[ ]DOMAIN
         |IP[ ]\d{1,3}[.]\d{1,3}[.]\d{1,3}[.]\d{1,3}[ ]is[ ]blocked[ ]by[ ]EarthLink # Earthlink
         |IP[/]domain[ ]reputation[ ]problems
-        |is[ ]not[ ]allowed[ ]to[ ]send[ ]mail[ ]from
+        |IPs[ ]with[ ]missing[ ]PTR[ ]records
+        |is[ ](?:
+             in[ ]a[ ]black[ ]list[ ]at[ ].+[.]
+            |in[ ]an[ ].*RBL[ ]on[ ].+
+            |not[ ]allowed[ ]to[ ]send[ ](?:
+                 mail[ ]from
+                |from[ ].+[ ]per[ ]it's[ ]SPF[ ]Record
+                )
+            )
         |mail[ ]server[ ]at[ ].+[ ]is[ ]blocked
+        |Mail[ ]from[ ]\d+[.]\d+[.]\d+[.]\d[ ]refused:
+        |Message[ ]from[ ].+[ ]rejected[ ]based[ ]on[ ]blacklist
         |Messages[ ]from[ ].+[ ]temporarily[ ]deferred[ ]due[ ]to[ ]user[ ]complaints   # Yahoo!
-        |no[ ]access[ ]from[ ]mail[ ]server
+        |no[ ](?:
+             access[ ]from[ ]mail[ ]server
+            |PTR[ ]Record[ ]found[.]
+            )
         |Not[ ]currently[ ]accepting[ ]mail[ ]from[ ]your[ ]ip  # Microsoft
-        |Please[ ]get[ ]a[ ]custom[ ]reverse[ ]DNS[ ]name[ ]from[ ]your[ ]ISP[ ]for[ ]your[ ]host
-        |please[ ]use[ ]the[ ]smtp[ ]server[ ]of[ ]your[ ]ISP
+        |part[ ]of[ ]their[ ]network[ ]is[ ]on[ ]our[ ]block[ ]list
+        |Please[ ](?:
+             get[ ]a[ ]custom[ ]reverse[ ]DNS[ ]name[ ]from[ ]your[ ]ISP[ ]for[ ]your[ ]host
+            |inspect[ ]your[ ]SPF[ ]settings
+            |use[ ]the[ ]smtp[ ]server[ ]of[ ]your[ ]ISP
+            )
+        |PTR[ ]record[ ]setup
         |Rejecting[ ]open[ ]proxy   # Sendmail(srvrsmtp.c)
+        |Reverse[ ]DNS[ ](?:
+              failed
+             |required
+             |lookup[ ]for[ ]host[ ].+[ ]failed[ ]permanently
+             )
+        |Sender[ ]IP[ ](?:
+             address[ ]rejected
+            |reverse[ ]lookup[ ]rejected
+            )
+        |Server[ ]access[ ](?:
+             .+[ ]forbidden[ ]by[ ]invalid[ ]RDNS[ ]record[ ]of[ ]your[ ]mail[ ]server
+            |forbidden[ ]by[ ]your[ ]IP[ ]
+            )
+        |Server[ ]IP[ ].+[ ]listed[ ]as[ ]abusive
+        |service[ ]permits[ ]\d+[ ]unverifyable[ ]sending[ ]IPs
+        |SMTP[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]initial[ ]connection:   # Exim
         |sorry,[ ](?:
              that[ ]domain[ ]isn'?t[ ]in[ ]my[ ]list[ ]of[ ]allowed[ ]rcpthosts
             |your[ ]remotehost[ ]looks[ ]suspiciously[ ]like[ ]spammer
             )
-        |SPF[ ]record
+        |SPF[ ](?:
+             .+[ ]domain[ ]authentication[ ]fail
+            |record
+            |check:[ ]fail
+            )
+        |SPF:[ ].+[ ]is[ ]not[ ]allowed[ ]to[ ]send[ ]mail.+[A-Z]{3}.+401
         |the[ ](?:email|domain|ip).+[ ]is[ ]blacklisted
+        |This[ ]system[ ]will[ ]not[ ]accept[ ]messages[ ]from[ ]servers[/]devices[ ]with[ ]no[ ]reverse[ ]DNS
+        |Too[ ]many[ ]spams[ ]from[ ]your[ ]IP  # free.fr
         |unresolvable[ ]relay[ ]host[ ]name
+        |Veuillez[ ]essayer[ ]plus[ ]tard.+[A-Z]{3}.+(?:103|510)
         |your[ ](?:
              network[ ]is[ ]temporary[ ]blacklisted
+            |sender's[ ]IP[ ]address[ ]is[ ]listed[ ]at[ ].+[.]abuseat[.]org
             |server[ ]requires[ ]confirmation
             )
         |was[ ]blocked[ ]by[ ].+
         |we[ ]do[ ]not[ ]accept[ ]mail[ ]from[ ](?: # @mail.ru
-             hosts[ ]with[ ]dynamic[ ]IP[ ]or[ ]generic[ ]dns[ ]PTR-records
-            |dynamic[ ]ips
+             dynamic[ ]ips
+            |hosts[ ]with[ ]dynamic[ ]IP[ ]or[ ]generic[ ]dns[ ]PTR-records
+            )
+        |You[ ]are[ ](?:
+             not[ ]allowed[ ]to[ ]connect
+            |sending[ ]spam
+            )
+        |Your[ ](?:
+             access[ ]to[ ]submit[ ]messages[ ]to[ ]this[ ]e-mail[ ]system[ ]has[ ]been[ ]rejected
+            |message[ ]was[ ]rejected[ ]for[ ]possible[ ]spam/virus[ ]content
             )
-        |http://www[.]spamcop[.]net/bl[.]
         )
     }xi;
 
