@@ -14,11 +14,14 @@ sub match {
     my $class = shift;
     my $argv1 = shift // return undef;
     my $regex = qr{(?> 
-         Insecure[ ]Mail[ ]Relay
+         as[ ]a[ ]relay
+        |Insecure[ ]Mail[ ]Relay
         |mail[ ]server[ ]requires[ ]authentication[ ]when[ ]attempting[ ]to[ ]
             send[ ]to[ ]a[ ]non-local[ ]e-mail[ ]address    # MailEnable 
-        |not[ ]allowed[ ]to[ ]relay[ ]through[ ]this[ ]machine
-        |Not[ ]an[ ]open[ ]relay,[ ]so[ ]get[ ]lost
+        |not[ ](?:
+             allowed[ ]to[ ]relay[ ]through[ ]this[ ]machine
+            |an[ ]open[ ]relay,[ ]so[ ]get[ ]lost
+            )
         |relay[ ](?:
              access[ ]denied
             |denied
@@ -26,6 +29,7 @@ sub match {
             )
         |relaying[ ]denied  # Sendmail
         |that[ ]domain[ ]isn[']t[ ]in[ ]my[ ]list[ ]of[ ]allowed[ ]rcpthost
+        |This[ ]system[ ]is[ ]not[ ]configured[ ]to[ ]relay[ ]mail
         |Unable[ ]to[ ]relay[ ]for
         )
     }ix;
@@ -111,7 +115,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
