@@ -31,34 +31,40 @@ sub match {
         |denied[ ]due[ ]to[ ]spam[ ]list
         |dt:spm[ ]mx.+[ ]http://mail[.]163[.]com/help/help_spam_16[.]htm
         |greylisted.?.[ ]please[ ]try[ ]again[ ]in
-        |http://(?:
-             www[.]spamhaus[.]org
-            |dsbl[.]org
-            |www[.]sorbs[.]net
-            )
+        |http://(?:www[.]spamhaus[.]org|dsbl[.]org)
         |listed[ ]in[ ]work[.]drbl[.]imedia[.]ru
         |mail[ ](?:
              appears[ ]to[ ]be[ ]unsolicited    # rejected due to spam
             |content[ ]denied   # http://service.mail.qq.com/cgi-bin/help?subtype=1&&id=20022&&no=1000726
+            |rejete.+[A-Z]{3}.+506
             )
         |may[ ]consider[ ]spam
         |message[ ](?:
-             content[ ]rejected
+             considered[ ]as[ ]spam[ ]or[ ]virus
+            |content[ ]rejected
             |filtered
-            |filtered[.][ ]please[ ]see[ ]the[ ]faqs[ ]section[ ]on[ ]spam
-            |filtered[.][ ]Refer[ ]to[ ]the[ ]Troubleshooting[ ]page[ ]at[ ]
+            |filtered[.][ ](?:
+                 please[ ]see[ ]the[ ]faqs[ ]section[ ]on[ ]spam
+                |Refer[ ]to[ ]the[ ]Troubleshooting[ ]page[ ]at[ ]
+                )
             |looks[ ]like[ ]spam
             |not[ ]accepted[ ]for[ ]policy[ ]reasons[.][ ]See[ ]http:   # Yahoo!
             |refused[ ]by[ ]mailmarshal[ ]spamprofiler
-            |rejected[ ]as[ ]spam
-            |rejected[ ]as[ ]spam[ ]by[ ]Content[ ]Filtering
-            |rejected[ ]due[ ]to[ ]suspected[ ]spam[ ]content
-            |rejected[ ]for[ ]policy[ ]reasons
+            |rejected[ ](?:
+                 as[ ]spam
+                |because[ ]of[ ]unacceptable[ ]content
+                |due[ ]to[ ]suspected[ ]spam[ ]content
+                |for[ ]policy[ ]reasons
+                )
+            )
+        |our[ ](?:
+             email[ ]server[ ]thinks[ ]this[ ]email[ ]is[ ]spam
+            |filters[ ]rate[ ]at[ ]and[ ]above[ ].+[ ]percent[ ]probability[ ]of[ ]being[ ]spam
+            |system[ ]has[ ]detected[ ]that[ ]this[ ]message[ ]is
             )
-        |our[ ]email[ ]server[ ]thinks[ ]this[ ]email[ ]is[ ]spam
-        |our[ ]filters[ ]rate[ ]at[ ]and[ ]above[ ].+[ ]percent[ ]probability[ ]of[ ]being[ ]spam
-        |our[ ]system[ ]has[ ]detected[ ]that[ ]this[ ]message[ ]is
         |probable[ ]spam
+        |REJECT[ ]bulk[.]advertising
+        |Reject,.+[ ][-][ ]SPAM[.][ ]
         |rejected(?:
              :[ ]spamassassin[ ]score[ ]
             |[ ]by[ ].+[ ][(]spam[)]
@@ -87,13 +93,24 @@ sub match {
         |spambouncer[ ]identified[ ]spam    # SpamBouncer identified SPAM
         |spamming[ ]not[ ]allowed
         |Too[ ]much[ ]spam[.]               # Earthlink
-        |the[ ]message[ ]was[ ]rejected[ ]due[ ]to[ ]classification[ ]as[ ]bulk[ ]mail
+        |the[ ]message[ ](?:
+             has[ ]been[ ]rejected[ ]by[ ]spam[ ]filtering[ ]engine
+            |was[ ]rejected[ ]due[ ]to[ ]classification[ ]as[ ]bulk[ ]mail
+            )
         |The[ ]content[ ]of[ ]this[ ]message[ ]looked[ ]like[ ]spam # SendGrid
+        |This[ ](?:e-mail|mail)[ ](?:
+             cannot[ ]be[ ]forwarded[ ]because[ ]it[ ]was[ ]detected[ ]as[ ]spam
+            |is[ ]classified[ ]as[ ]spam[ ]and[ ]is[ ]rejected
+            )
         |this[ ]message[ ](?:
              appears[ ]to[ ]be[ ]spam
-            |has[ ]been[ ]identified[ ]as[ ]spam
+            |has[ ]been[ ](?:
+                 identified[ ]as[ ]spam
+                |scored[ ]as[ ]spam[ ]with[ ]a[ ]probability
+                )
             |scored[ ].+[ ]spam[ ]points
             |was[ ]classified[ ]as[ ]spam
+            |was[ ]rejected[ ]by[ ]Recurrent[ ]Pattern[ ]Detection[ ]System
             )
         |transaction[ ]failed[ ]spam[ ]message[ ]not[ ]queued       # SendGrid
         |we[ ]dont[ ]accept[ ]spam
@@ -103,12 +120,12 @@ sub match {
                  appears[ ]similar[ ]to[ ]spam[ ]we[ ]have[ ]received[ ]before
                 |breaches[ ]local[ ]URIBL[ ]policy
                 |had[ ]spam[-]like[ ]
-                |is[ ]considered[ ]spam
-                |is[ ]probably[ ]spam
+                |is[ ](?:considered|probably)[ ]spam
                 |was[ ]detected[ ]as[ ]spam
                 )
             |message[ ](?:
-                 has[ ]been[ ](?:
+                 as[ ]spam[ ]and[ ]has[ ]prevented[ ]delivery
+                |has[ ]been[ ](?:
                      temporarily[ ]blocked[ ]by[ ]our[ ]filter
                     |rejected[ ]because[ ]it[ ]appears[ ]to[ ]be[ ]SPAM
                     )
