@@ -17,65 +17,82 @@ sub match {
          .+[ ]user[ ]unknown
         |[#]5[.]1[.]1[ ]bad[ ]address
         |[<].+[>][ ]not[ ]found
-        |address[ ]does[ ]not[ ]exist
-        |address[ ]unknown
+        |[<].+[@].+[>][.][.][.][ ]Blocked[ ]by[ ]
+        |5[.]0[.]0[.][ ]Mail[ ]rejected[.]
+        |5[.]1[.]0[ ]Address[ ]rejected[.]
+        |Adresse[ ]d[ ]au[ ]moins[ ]un[ ]destinataire[ ]invalide.+[A-Z]{3}.+(?:416|418)
+        |address[ ](?:does[ ]not[ ]exist|unknown)
         |archived[ ]recipient
         |BAD[-_ \t]RECIPIENT
         |can[']t[ ]accept[ ]user
-        |destination[ ]addresses[ ]were[ ]unknown
-        |destination[ ]server[ ]rejected[ ]recipients
-        |email[ ]address[ ]does[ ]not[ ]exist
+        |destination[ ](?:
+             addresses[ ]were[ ]unknown
+            |server[ ]rejected[ ]recipients
+            )
+        |email[ ]address[ ](?:does[ ]not[ ]exist|could[ ]not[ ]be[ ]found)
         |invalid[ ](?:
              address
-            |mailbox[ ]path
-            |recipient                 # Linkedin
+            |mailbox:
+            |mailbox[ ]path|recipient
             )
         |is[ ]not[ ](?:
              a[ ]known[ ]user
+            |a[ ]valid[ ]mailbox
             |an[ ]active[ ]address[ ]at[ ]this[ ]host
             )
         |mailbox[ ](?:
-             not[ ]present
-            |not[ ]found
+             .+[ ]does[ ]not[ ]exist
+            |.+[@].+[ ]unavailable
+            |invalid
+            |is[ ](?:inactive|unavailable)
+            |not[ ](?:present|found)
             |unavailable
             )
         |no[ ](?:
-             account[ ]by[ ]that[ ]name[ ]here
+             [ ].+[ ]in[ ]name[ ]directory
+            |account[ ]by[ ]that[ ]name[ ]here
+            |existe[ ](?:dicha[ ]persona|ese[ ]usuario[ ])
             |mail[ ]box[ ]available[ ]for[ ]this[ ]user
-            |mailbox[ ]found
+            |mailbox[ ](?:
+                 by[ ]that[ ]name[ ]is[ ]currently[ ]available
+                |found
+                )
             |matches[ ]to[ ]nameserver[ ]query
             |such[ ](?:
-                 mailbox
+                 address[ ]here
+                |mailbox
                 |person[ ]at[ ]this[ ]address
                 |recipient
                 |user(?:[ ]here)?
                 )
-            |[ ].+[ ]in[ ]name[ ]directory
+            |thank[ ]you[ ]rejected:[ ]Account[ ]Unavailable:
             |valid[ ]recipients[,][ ]bye    # Microsoft
             )
         |non[- ]?existent[ ]user
         |not[ ](?:
              a[ ]valid[ ]user[ ]here
             |a[ ]local[ ]address
+            |email[ ]addresses
             )
         |rcpt[ ][<].+[>][ ]does[ ]not[ ]exist
-        |recipient[ ](?:
+        |rece?ipient[ ](?:
              .+[ ]was[ ]not[ ]found[ ]in
             |address[ ]rejected:[ ](?:
-                 invalid[ ]user
+                 Access[ ]denied
+                |invalid[ ]user
                 |user[ ].+[ ]does[ ]not[ ]exist
                 |user[ ]unknown[ ]in[ ].+[ ]table
                 |unknown[ ]user
                 )
             |does[ ]not[ ]exist(?:[ ]on[ ]this[ ]system)?
             |is[ ]not[ ]local
-            |not[ ]found
-            |not[ ]OK
+            |not[ ](?:exist|found|OK)
             |unknown
             )
         |requested[ ]action[ ]not[ ]taken:[ ]mailbox[ ]unavailable
-        |RESOLVER[.]ADR[.]RecipNotFound # Microsoft
+        |RESOLVER[.]ADR[.]Recip(?:ient)NotFound # Microsoft
         |said:[ ]550[-[ ]]5[.]1[.]1[ ].+[ ]user[ ]unknown[ ]
+        |SMTP[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]end[ ]of[ ]data:[ ]553.+does[ ]not[ ]exist
         |sorry,[ ](?:
              user[ ]unknown
             |badrcptto
@@ -86,9 +103,11 @@ sub match {
             |following[ ]recipients[ ]was[ ]undeliverable
             |user[']s[ ]email[ ]name[ ]is[ ]not[ ]found
             )
+        |There[ ]is[ ]no[ ]one[ ]at[ ]this[ ]address
         |this[ ](?:
              address[ ]no[ ]longer[ ]accepts[ ]mail
             |email[ ]address[ ]is[ ]wrong[ ]or[ ]no[ ]longer[ ]valid
+            |spectator[ ]does[ ]not[ ]exist
             |user[ ]doesn[']?t[ ]have[ ]a[ ].+[ ]account
             )
         |unknown[ ](?:
@@ -103,11 +122,11 @@ sub match {
             |.+[ ]does[ ]not[ ]exist
             |does[ ]not[ ]exist
             |missing[ ]home[ ]directory
-            |not[ ]found     # 550 User not found. See http://mail.bigmir.net/err/2/
-            |not[ ]known
+            |not[ ](?:active|found|known)
             |unknown
             )
         |vdeliver:[ ]invalid[ ]or[ ]unknown[ ]virtual[ ]user
+        |your[ ]envelope[ ]recipient[ ]is[ ]in[ ]my[ ]badrcptto[ ]list
         )
     }xi;
 
@@ -129,7 +148,10 @@ sub true {
     return 1 if $argvs->reason eq __PACKAGE__->text;
 
     require Sisimai::SMTP::Status;
-    my $prematches = ['NoRelaying', 'Blocked', 'MailboxFull', 'HasMoved'];
+    my $prematches = [
+        'NoRelaying', 'Blocked', 'MailboxFull', 'HasMoved',
+        'Blocked', 'Rejected',
+    ];
     my $matchother = 0;
     my $statuscode = $argvs->deliverystatus // '';
     my $diagnostic = $argvs->diagnosticcode // '';
