@@ -6,8 +6,9 @@ use Module::Load '';
 
 my $RhostClass = {
     qr/\Aaspmx[.]l[.]google[.]com\z/                   => 'GoogleApps',
-    qr/[.]protection[.]outlook[.]com\z/                => 'ExchangeOnline',
+    qr/[.](?:prod|protection)[.]outlook[.]com\z/       => 'ExchangeOnline',
     qr/\A(?:smtp|mailstore1)[.]secureserver[.]net\z/   => 'GoDaddy',
+    qr/\b(?:laposte[.]net|orange[.]fr)\z/              => 'FrancePTT',
 };
 
 sub list {
